==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALocalImmediate.h <==
// public final class soot.jimple.parser.node.ALocalImmediate

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3e48bf6191d251ac soot_jimple_parser_node_ALocalImmediate
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class e5ba3870b9b1dbcc soot_jimple_parser_node_PImmediate

// header file dependencies
// @dep_header soot_jimple_parser_node_PImmediate

#include "soot/jimple/parser/node/PImmediate.h"

#ifndef _JC_soot_jimple_parser_node_ALocalImmediate_H_
#define _JC_soot_jimple_parser_node_ALocalImmediate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PLocalName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_refs	_jc_soot_jimple_parser_node_ALocalImmediate$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs	_jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$refs	_jc_soot_jimple_parser_node_ALocalImmediate$refs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$nonrefs	_jc_soot_jimple_parser_node_ALocalImmediate$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$object	_jc_soot_jimple_parser_node_ALocalImmediate$object;

typedef const struct _jc_soot_jimple_parser_node_ALocalImmediate$vmethods	_jc_soot_jimple_parser_node_ALocalImmediate$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALocalImmediate$vtable	_jc_soot_jimple_parser_node_ALocalImmediate$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALocalImmediate$vtype	_jc_soot_jimple_parser_node_ALocalImmediate$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$_init$e17ded02c1f5a7bc(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALocalImmediate$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);
extern struct _jc_soot_jimple_parser_node_PLocalName$object *_jc_soot_jimple_parser_node_ALocalImmediate$method$getLocalName$6abeca666d69d27d(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$setLocalName$e0082a9faf2824c3(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALocalImmediate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$getLocalName$6abeca666d69d27d;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$setLocalName$e0082a9faf2824c3;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALocalImmediate$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);
	struct _jc_soot_jimple_parser_node_PLocalName$object	*(*getLocalName$6abeca666d69d27d)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setLocalName$e0082a9faf2824c3)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALocalImmediate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PImmediate$vmethods	soot_jimple_parser_node_PImmediate;
	_jc_soot_jimple_parser_node_ALocalImmediate$vmethods	soot_jimple_parser_node_ALocalImmediate;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALocalImmediate$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALocalImmediate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_refs {
	struct _jc_soot_jimple_parser_node_PLocalName$object	*__5flocalName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalImmediate$refs {
    _jc_soot_jimple_parser_node_ALocalImmediate$sub_refs	soot_jimple_parser_node_ALocalImmediate;
    _jc_soot_jimple_parser_node_PImmediate$sub_refs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalImmediate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PImmediate$sub_nonrefs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs	soot_jimple_parser_node_ALocalImmediate;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALocalImmediate$object {
	_jc_soot_jimple_parser_node_ALocalImmediate$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALocalImmediate$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALocalImmediate$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALocalImmediate$vtype _jc_soot_jimple_parser_node_ALocalImmediate$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALocalImmediate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALocalImmediate$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALocalImmediate_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALocalImmediate.h <==
// public final class soot.jimple.parser.node.ALocalImmediate

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3e48bf6191d251ac soot_jimple_parser_node_ALocalImmediate
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class e5ba3870b9b1dbcc soot_jimple_parser_node_PImmediate

// header file dependencies
// @dep_header soot_jimple_parser_node_PImmediate

#include "soot/jimple/parser/node/PImmediate.h"

#ifndef _JC_soot_jimple_parser_node_ALocalImmediate_H_
#define _JC_soot_jimple_parser_node_ALocalImmediate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PLocalName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_refs	_jc_soot_jimple_parser_node_ALocalImmediate$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs	_jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$refs	_jc_soot_jimple_parser_node_ALocalImmediate$refs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$nonrefs	_jc_soot_jimple_parser_node_ALocalImmediate$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalImmediate$object	_jc_soot_jimple_parser_node_ALocalImmediate$object;

typedef const struct _jc_soot_jimple_parser_node_ALocalImmediate$vmethods	_jc_soot_jimple_parser_node_ALocalImmediate$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALocalImmediate$vtable	_jc_soot_jimple_parser_node_ALocalImmediate$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALocalImmediate$vtype	_jc_soot_jimple_parser_node_ALocalImmediate$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$_init$e17ded02c1f5a7bc(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALocalImmediate$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PLocalName$object *_jc_soot_jimple_parser_node_ALocalImmediate$method$getLocalName$6abeca666d69d27d(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalImmediate$method$setLocalName$e0082a9faf2824c3(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALocalImmediate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$getLocalName$6abeca666d69d27d;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$setLocalName$e0082a9faf2824c3;
extern _jc_method _jc_soot_jimple_parser_node_ALocalImmediate$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALocalImmediate$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PLocalName$object	*(*getLocalName$6abeca666d69d27d)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setLocalName$e0082a9faf2824c3)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *, struct _jc_soot_jimple_parser_node_PLocalName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalImmediate$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALocalImmediate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PImmediate$vmethods	soot_jimple_parser_node_PImmediate;
	_jc_soot_jimple_parser_node_ALocalImmediate$vmethods	soot_jimple_parser_node_ALocalImmediate;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALocalImmediate$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALocalImmediate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_refs {
	struct _jc_soot_jimple_parser_node_PLocalName$object	*__5flocalName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalImmediate$refs {
    _jc_soot_jimple_parser_node_ALocalImmediate$sub_refs	soot_jimple_parser_node_ALocalImmediate;
    _jc_soot_jimple_parser_node_PImmediate$sub_refs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalImmediate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PImmediate$sub_nonrefs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_ALocalImmediate$sub_nonrefs	soot_jimple_parser_node_ALocalImmediate;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALocalImmediate$object {
	_jc_soot_jimple_parser_node_ALocalImmediate$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALocalImmediate$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALocalImmediate$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALocalImmediate$vtype _jc_soot_jimple_parser_node_ALocalImmediate$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALocalImmediate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALocalImmediate$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALocalImmediate_H_ */
